window.Gleam.initSearch([{"doc":"glistix_json","title":"glistix_json","content":"# json 🐑\n\n**Mirrors:** [**GitHub**](https://github.com/glistix/json) | [**Codeberg**](https://codeberg.org/glistix/json)\n\n[![Nix-compatible](https://img.shields.io/badge/target-nix-5277C3)](https://github.com/glistix/glistix)\n\nWork with JSON in [Glistix](https://github.com/glistix/glistix)!\n\nThis is a fork of [`gleam_json`](https://github.com/gleam-lang/json) which **adds support for Glistix&#39;s Nix target**.\n\n## Incompatibilities\n\nPlease note that, currently, **JSON decoding (the `decode` function) will crash when receiving invalid JSON input on the Nix target** instead of gracefully failing and returning an `Error`.\n\nThis is because it uses `builtins.fromJSON` which aborts execution on invalid input. A fix for this while retaining efficiency would likely depend on changes to Nix itself.\n\n## Installation\n\nYou can use this fork by running `glistix add gleam_json` followed by adding the line below to your Glistix project&#39;s `gleam.toml` file (as of Glistix v0.7.0):\n\n```toml\n[glistix.preview.patch]\n# ... Existing patches ...\n# Add this line:\ngleam_json = { name = &quot;glistix_json&quot;, version = &quot;&gt;= 1.0.0 and &lt; 2.0.0&quot; }\n```\n\nThis ensures transitive dependencies on `gleam_json` will also use the patch.\n\nFor the most recent instructions, please see [the Glistix handbook](https://glistix.github.io/book/recipes/overriding-packages.html).\n\n### Encoding\n\n```gleam\nimport myapp.{Cat}\nimport gleam/json.{object, string, array, int, null}\n\npub fn cat_to_json(cat: Cat) -&gt; String {\n  object([\n    #(&quot;name&quot;, string(cat.name)),\n    #(&quot;lives&quot;, int(cat.lives)),\n    #(&quot;flaws&quot;, null()),\n    #(&quot;nicknames&quot;, array(cat.nicknames, of: string)),\n  ])\n  |&gt; json.to_string\n}\n```\n\n### Decoding\n\nJSON is decoded into a `Dynamic` value which can be decoded using the\n`gleam/dynamic` module from the Gleam standard library.\n\n&gt; [!WARNING]\n&gt;\n&gt; On the Nix target, invalid JSON input will cause a crash instead of\n&gt; returning an `Error`. Ensure you always provide valid JSON input.\n\n```gleam\nimport myapp.{Cat}\nimport gleam/json\nimport gleam/dynamic.{field, list, int, string}\n\npub fn cat_from_json(json_string: String) -&gt; Result(Cat, json.DecodeError) {\n  let cat_decoder = dynamic.decode3(\n    Cat,\n    field(&quot;name&quot;, of: string),\n    field(&quot;lives&quot;, of: int),\n    field(&quot;nicknames&quot;, of: list(string)),\n  )\n\n  json.decode(from: json_string, using: cat_decoder)\n}\n```\n","url":"index.html"},{"doc":"gleam/json","title":"DecodeError","content":"pub type DecodeError {\n  UnexpectedEndOfInput\n  UnexpectedByte(byte: String, position: Int)\n  UnexpectedSequence(byte: String, position: Int)\n  UnexpectedFormat(List(dynamic.DecodeError))\n}\n\nUnexpectedEndOfInput\n\n\nUnexpectedByte(byte: String, position: Int)\n\n\nUnexpectedSequence(byte: String, position: Int)\n\n\nUnexpectedFormat(List(dynamic.DecodeError))\n\n\nSynonyms:\ngleam/json.DecodeError\ngleam/json DecodeError","url":"gleam/json.html#DecodeError"},{"doc":"gleam/json","title":"Json","content":"pub type Json\n\n\nSynonyms:\ngleam/json.Json\ngleam/json Json","url":"gleam/json.html#Json"},{"doc":"gleam/json","title":"array","content":"pub fn array(\n  from entries: List(a),\n  of inner_type: fn(a) -&gt; Json,\n) -&gt; Json\n Encode a list into a JSON array.\n\n ## Examples\n\n \n &gt; to_string(array([1, 2, 3], of: int))\n &quot;[1, 2, 3]&quot;\n \n\nSynonyms:\ngleam/json.array\ngleam/json array","url":"gleam/json.html#array"},{"doc":"gleam/json","title":"bool","content":"pub fn bool(input: Bool) -&gt; Json\n Encode a bool into JSON.\n\n ## Examples\n\n \n &gt; to_string(bool(False))\n &quot;false&quot;\n \n\nSynonyms:\ngleam/json.bool\ngleam/json bool","url":"gleam/json.html#bool"},{"doc":"gleam/json","title":"decode","content":"pub fn decode(\n  from json: String,\n  using decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, gleam/json.DecodeError)\n Decode a JSON string into dynamically typed data which can be decoded into\n typed data with the `gleam/dynamic` module.\n\n ## Warning\n\n On the Nix target, this function will crash Nix evaluation if an invalid\n JSON string is given, due to current limitations. Please ensure the given\n JSON is valid beforehand.\n\n ## Examples\n\n \n &gt; decode(&quot;[1,2,3]&quot;, dynamic.list(of: dynamic.int))\n Ok([1, 2, 3])\n \n\n \n &gt; decode(&quot;[&quot;, dynamic.list(of: dynamic.int))\n Error(UnexpectedEndOfInput)\n \n\n \n &gt; decode(&quot;1&quot;, dynamic.string)\n Error(UnexpectedFormat([dynamic.DecodeError(&quot;String&quot;, &quot;Int&quot;, [])]))\n \n\nSynonyms:\ngleam/json.decode\ngleam/json decode","url":"gleam/json.html#decode"},{"doc":"gleam/json","title":"decode_bits","content":"pub fn decode_bits(\n  from json: BitArray,\n  using decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, gleam/json.DecodeError)\n Decode a JSON bit string into dynamically typed data which can be decoded\n into typed data with the `gleam/dynamic` module.\n\n ## Warning\n\n On the Nix target, this function will interrupt evaluation if an invalid\n JSON string is given, due to current limitations. Please ensure the given\n JSON is valid beforehand.\n\n ## Examples\n\n \n &gt; decode_bits(&lt;&lt;&quot;[1,2,3]&quot;&gt;&gt;, dynamic.list(of: dynamic.int))\n Ok([1, 2, 3])\n \n\n \n &gt; decode_bits(&lt;&lt;&quot;[&quot;&gt;&gt;, dynamic.list(of: dynamic.int))\n Error(UnexpectedEndOfInput)\n \n\n \n &gt; decode_bits(&quot;&lt;&lt;1&quot;&gt;&gt;, dynamic.string)\n Error(UnexpectedFormat([dynamic.DecodeError(&quot;String&quot;, &quot;Int&quot;, [])]))\n \n\nSynonyms:\ngleam/json.decode_bits\ngleam/json decode_bits","url":"gleam/json.html#decode_bits"},{"doc":"gleam/json","title":"float","content":"pub fn float(input: Float) -&gt; Json\n Encode an float into JSON.\n\n ## Examples\n\n \n &gt; to_string(float(4.7))\n &quot;4.7&quot;\n \n\nSynonyms:\ngleam/json.float\ngleam/json float","url":"gleam/json.html#float"},{"doc":"gleam/json","title":"int","content":"pub fn int(input: Int) -&gt; Json\n Encode an int into JSON.\n\n ## Examples\n\n \n &gt; to_string(int(50))\n &quot;50&quot;\n \n\nSynonyms:\ngleam/json.int\ngleam/json int","url":"gleam/json.html#int"},{"doc":"gleam/json","title":"null","content":"pub fn null() -&gt; Json\n The JSON value null.\n\n ## Examples\n\n \n &gt; to_string(null())\n &quot;null&quot;\n \n\nSynonyms:\ngleam/json.null\ngleam/json null","url":"gleam/json.html#null"},{"doc":"gleam/json","title":"nullable","content":"pub fn nullable(\n  from input: Option(a),\n  of inner_type: fn(a) -&gt; Json,\n) -&gt; Json\n Encode an optional value into JSON, using null if it the `None` variant.\n\n ## Examples\n\n \n &gt; to_string(nullable(Some(50), of: int))\n &quot;50&quot;\n \n\n \n &gt; to_string(nullable(None, of: int))\n &quot;null&quot;\n \n\nSynonyms:\ngleam/json.nullable\ngleam/json nullable","url":"gleam/json.html#nullable"},{"doc":"gleam/json","title":"object","content":"pub fn object(entries: List(#(String, Json))) -&gt; Json\n Encode a list of key-value pairs into a JSON object.\n\n ## Examples\n\n \n &gt; to_string(object([\n   #(&quot;game&quot;, string(&quot;Pac-Man&quot;)),\n   #(&quot;score&quot;, int(3333360)),\n ]))\n &quot;{\\&quot;game\\&quot;:\\&quot;Pac-Mac\\&quot;,\\&quot;score\\&quot;:3333360}&quot;\n \n\nSynonyms:\ngleam/json.object\ngleam/json object","url":"gleam/json.html#object"},{"doc":"gleam/json","title":"preprocessed_array","content":"pub fn preprocessed_array(from: List(Json)) -&gt; Json\n Encode a list of JSON values into a JSON array.\n\n ## Examples\n\n \n &gt; to_string(preprocessed_array([int(1), float(2.0), string(&quot;3&quot;)]))\n &quot;[1, 2.0, \\&quot;3\\&quot;]&quot;\n \n\nSynonyms:\ngleam/json.preprocessed_array\ngleam/json preprocessed_array","url":"gleam/json.html#preprocessed_array"},{"doc":"gleam/json","title":"string","content":"pub fn string(input: String) -&gt; Json\n Encode a string into JSON, using normal JSON escaping.\n\n ## Examples\n\n \n &gt; to_string(&quot;Hello!&quot;)\n &quot;\\&quot;Hello!\\&quot;&quot;\n \n\nSynonyms:\ngleam/json.string\ngleam/json string","url":"gleam/json.html#string"},{"doc":"gleam/json","title":"to_string","content":"pub fn to_string(json: Json) -&gt; String\n Convert a JSON value into a string.\n\n Where possible prefer the `to_string_builder` function as it is faster than\n this function, and BEAM VM IO is optimised for sending `StringBuilder` data.\n\n ## Examples\n\n \n &gt; to_string(array([1, 2, 3], of: int))\n &quot;[1,2,3]&quot;\n \n\nSynonyms:\ngleam/json.to_string\ngleam/json to_string","url":"gleam/json.html#to_string"},{"doc":"gleam/json","title":"to_string_builder","content":"pub fn to_string_builder(json: Json) -&gt; StringBuilder\n Convert a JSON value into a string builder.\n\n Where possible prefer this function to the  `to_string` function as it is\n slower than this function, and BEAM VM IO is optimised for sending\n `StringBuilder` data.\n\n ## Examples\n\n \n &gt; to_string_builder(array([1, 2, 3], of: int))\n string_builder.from_string(&quot;[1,2,3]&quot;)\n \n\nSynonyms:\ngleam/json.to_string_builder\ngleam/json to_string_builder","url":"gleam/json.html#to_string_builder"},{"doc":"gleam/json","title":"gleam/json","content":"","url":"gleam/json.html"}]);